@@ -41,9 +41,17 @@ if __name__ == '__main__':
         south = ()
 
     from django.conf import settings, global_settings
+    INSTALLED_APPS = (
+        'django.contrib.admin',
+        'django.contrib.auth',
+        'django.contrib.contenttypes',
+        'django.contrib.sessions',
+        'django.contrib.messages',
+        'django.contrib.staticfiles',
+    )
     if not settings.configured:
         settings.configure(
-            INSTALLED_APPS=global_settings.INSTALLED_APPS + south + ('%(apps_available)s',),
+            INSTALLED_APPS=INSTALLED_APPS + south + ('%(apps_available)s',),
             DATABASES={'default': {'ENGINE': 'django.db.backends.sqlite3'}},
             MIDDLEWARE_CLASSES=global_settings.MIDDLEWARE_CLASSES,  # Prevents Django 1.7 warning.
             SOUTH_MIGRATION_MODULES = {%(south_migration_modules)s}
@@ -347,6 +355,22 @@ class DevTools(object):
 
         default_venv_path = self._get_venv_path(DJANGO_DEFAULT_VERSION)
 
+        def fix_migrations(path):
+            """Fixes buggy migrations created with `makemigrations` using Py2.
+            See: https://code.djangoproject.com/ticket/23455
+
+            :param path:
+            :return:
+            """
+            self.logger.info('Fixing migrations ...')
+            for file in os.listdir(path):
+                if os.path.splitext(file)[1] == '.py':
+                    with open(os.path.join(path, file), 'r+') as f:
+                        contents = f.read()
+                        f.seek(0)
+                        f.write(contents.replace("=b'", "='"))
+                        f.truncate()
+
         for venv in venvs:
             venv_path = self._get_venv_path(venv)
 
@@ -373,6 +397,8 @@ class DevTools(object):
                         flag = '--init'
                     self.run_manage_command('schemamigration %s %s' % (app_name, flag), venv_path, verbose=False)
 
+                fix_migrations(PATH_BUILTIN)
+
 
 def main():
     arg_parser = argparse.ArgumentParser(prog='django-dev', description='Tools to facilitate application development for Django', version='.'.join(map(str, VERSION)))
